==> seedsui-react-5.7.93.tgz: package/lib/Cascader/DistrictMain/utils/matchType.js <==
import testMunicipality from "./testMunicipality";
import testCountry from "./testCountry";
import testProvince from "./testProvince";
import testCity from "./testCity";
import testDistrict from "./testDistrict";
import testStreet from "./testStreet";
import testNodeData from "./testNodeData";

// 主方法: 匹配当前选中项的类型, tabs支持array和object两种方式, array匹配将会更准确
function matchType(tabs, config) {
  var _current, _current2, _current3, _current4;
  var _ref = config || {},
    data = _ref.data,
    isCountry = _ref.isCountry,
    isProvince = _ref.isProvince,
    isMunicipality = _ref.isMunicipality,
    isCity = _ref.isCity,
    isDistrict = _ref.isDistrict,
    isStreet = _ref.isStreet;
  if (!window.AreaLevel) return null;

  // Array type parameter is invalid
  if (Array.isArray(tabs) && !tabs.length) {
    return null;
  }
  var current = Array.isArray(tabs) ? tabs[tabs.length - 1] : tabs;

  // Current is invalid
  if (!((_current = current) !== null && _current !== void 0 && _current.id) && !((_current2 = current) !== null && _current2 !== void 0 && _current2.name)) {
    return null;
  }

  // Current No id and No parentid, It's root
  if (!((_current3 = current) !== null && _current3 !== void 0 && _current3.id) && !((_current4 = current) !== null && _current4 !== void 0 && _current4.parentid) && Array.isArray(data) && data.length) {
    current = data[0];
  }
  if (testMunicipality(current, isMunicipality)) {
    return ['province', 'city'];
  }
  if (testCountry(current, isCountry)) {
    return ['country'];
  }
  if (testProvince(current, isProvince)) {
    return ['province'];
  }
  if (testCity(current, isCity)) {
    return ['city'];
  }
  if (testDistrict(current, isDistrict)) {
    return ['district'];
  }
  if (testStreet(current, isStreet)) {
    return ['street'];
  }
  // 不是省市，但在data中，则认为是区，不在data中，则认为是街道(街道在data中, 会有isStreet，所以在isStreet时就返回了)
  if (testNodeData(current, data)) {
    return ['district'];
  }

  // 没有类型则可能是街道，如果上级是区或者市，则必定是街道
  if (Array.isArray(tabs) && tabs.length > 2) {
    var prevTab = tabs[tabs.length - 2];
    if (testDistrict(prevTab, isDistrict)) {
      return ['street'];
    }
    if (testCity(prevTab, isCity)) {
      return ['street'];
    }
  }
  return null;
}
export default matchType;

==> seedsui-react-5.8.7.tgz: package/lib/Cascader/DistrictMain/utils/matchType.js <==
import testMunicipality from "./testMunicipality";
import testCountry from "./testCountry";
import testProvince from "./testProvince";
import testCity from "./testCity";
import testDistrict from "./testDistrict";
import testStreet from "./testStreet";
import testNodeData from "./testNodeData";

// 主方法: 匹配当前选中项的类型, tabs支持array和object两种方式, array匹配将会更准确
function matchType(tabs, config) {
  var _current, _current2, _current3, _current4;
  var _ref = config || {},
    data = _ref.data,
    isCountry = _ref.isCountry,
    isProvince = _ref.isProvince,
    isMunicipality = _ref.isMunicipality,
    isCity = _ref.isCity,
    isDistrict = _ref.isDistrict,
    isStreet = _ref.isStreet;
  if (!window.AreaLevel) return null;

  // Array type parameter is invalid
  if (Array.isArray(tabs) && !tabs.length) {
    return null;
  }
  var current = Array.isArray(tabs) ? tabs[tabs.length - 1] : tabs;

  // 最后一级为请选择, 向上选一级
  if (!((_current = current) !== null && _current !== void 0 && _current.id) && current.parentid) {
    current = tabs[tabs.length - 2];
  }

  // Current is invalid
  if (!((_current2 = current) !== null && _current2 !== void 0 && _current2.id)) {
    return null;
  }

  // Current No id and No parentid, It's root
  if (!((_current3 = current) !== null && _current3 !== void 0 && _current3.id) && !((_current4 = current) !== null && _current4 !== void 0 && _current4.parentid) && Array.isArray(data) && data.length) {
    current = data[0];
  }
  if (testMunicipality(current, isMunicipality)) {
    return ['province', 'city'];
  }
  if (testCountry(current, isCountry)) {
    return ['country'];
  }
  if (testProvince(current, isProvince)) {
    return ['province'];
  }
  if (testCity(current, isCity)) {
    return ['city'];
  }
  if (testStreet(current, isStreet)) {
    return ['street'];
  }
  if (testDistrict(current, isDistrict)) {
    return ['district'];
  }
  // 不是省市，但在data中，则认为是区，不在data中，则认为是街道(街道在data中, 会有isStreet，所以在isStreet时就返回了)
  if (testNodeData(current, data)) {
    return ['district'];
  }

  // 没有类型则可能是街道，如果上级是区或者市，则必定是街道
  if (Array.isArray(tabs) && tabs.length > 2) {
    return ['street'];
  }
  return null;
}
export default matchType;
